#define __IO volatile
#define __I volatile
#define __O volatile
#include "hsm.h"
#include "component/hsm.h"
#include <xc.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

static const uint32_t HsmFwMdLoc = 0x0c0df800;
uint32_t * HFML= (uint32_t *)HsmFwMdLoc ;
uint32_t secureBootPassed = 0;

#define HSM_TEST_SBC_SEQUENTIAL

void hsmTests()
{
    uint32_t ctrla = HSM_REGS->HSM_CTRLA;
    uint32_t sbc = HSM_SBC_DISABLED;
    // Is the HSM Enabled?
    if ((ctrla & HSM_CTRLA_ENABLE_Msk) == 0)
    {
        ctrla |= HSM_CTRLA_ENABLE(1);
        HSM_REGS->HSM_CTRLA = ctrla;
    }
    uint32_t status = HSM_REGS->HSM_STATUS;
    
#if defined(HSM_TEST_SBC_SEQUENTIAL) || defined (HSM_TEST_SBC_SIMULTANEOUS)
    //printf("load firmware \r\n"); 
    TxLoadFirmware(HsmFwMdLoc);
    
        
#if defined (HSM_TEST_SBC_SEQUENTIAL)
     //printf("Receive load firmware \r\n"); 
     RxLoadFirmware();
#endif
     status = HSM_REGS->HSM_STATUS;
#endif
    
    if (((status & HSM_STATUS_PS_Msk) >> HSM_STATUS_PS_Pos) == HSM_PS_BOOT)
    {
        //printf("HSM IS IN BOOT STATE \r\n"); 
        uint32_t status1 = (status & HSM_STATUS_SBS_Msk);
        status1 = status1 >> HSM_STATUS_SBS_Pos;
        
        if (((status & HSM_STATUS_SBS_Msk)>>HSM_STATUS_SBS_Pos) == HSM_SBS_DISABLED)
        {
            // Secure Boot Disabled.  Need to Load Firmware
            printf("SECURE BOOT IS DISABLED, NEED TO LOAD FIRMWARE \r\n"); 
            TxRxLoadFirmware(HsmFwMdLoc);
            sbc = HSM_SBC_DISABLED;
        }
        else
        {
            // Secure Boot is enabled, need to determine which mode
            //printf("SECURE BOOT IS ENABLED  \r\n"); 
            uint32_t hsmStatus = HSM_REGS->HSM_STATUS;

            // Make sure the HSM is not currently processing the MetaData provided by the ROM
            while (((hsmStatus & HSM_STATUS_BUSY_Msk) != 0))
            {
                hsmStatus = HSM_REGS->HSM_STATUS;        
            }
            // Get the RX status of the Mailbox
            uint32_t mbRxStatus = HSM_REGS->HSM_MBRXSTATUS;            
            
            if((mbRxStatus & HSM_MBRXSTATUS_RXINT_Msk) != 0)
            {
                // Simultaneous Secure Boot.  Need to receive the Message
                printf("SIMULTANEOUS SECURE BOOT is ENABLED\r\n"); 
                RxLoadFirmware();      
                sbc = HSM_SBC_SIMULTANEOUS;
            }
            else
            {
                // Sequential Secure Boot
                printf("SEQUENTIAL SECURE BOOT is ENABLED\r\n"); 
                sbc = HSM_SBC_SEQUENTIAL;
            }
        }
        if (sbc != HSM_SBC_DISABLED)
        {
            printf("FIANLIZE SECURE BOOT \r\n"); 
            TxRxBtFinalizeSb(1);
        }
        //printf("GETSBC \r\n"); 
        TxRxGetSBC();
    }
    else if (((status & HSM_STATUS_PS_Msk) >> HSM_STATUS_PS_Pos)== HSM_PS_OPERATION)
    {
        // Secure Boot is done either way.
        printf("SECURE BOOT IS DONE EITHER WAY , GETSBC \r\n"); 
        TxRxGetSBC();
        
    }
    else
    {
        printf("ENTERED SAFE MODE \r\n"); // Safe Mode
    }
     status =  HSM_REGS->HSM_STATUS;
     if (((status & HSM_STATUS_SBS_Msk)>>HSM_STATUS_SBS_Pos) == HSM_SBS_PASSED)    
     {
         printf("SECURE BOOT IS PASSED \r\n"); 
         secureBootPassed = 1;
     }
     
}

uint32_t TxMbMsg(uint32_t * Req)
{
    // Wait for the TXInt to be available, and the hsm not to be busy.
    uint32_t mbTxStatus = HSM_REGS->HSM_MBTXSTATUS;
    uint32_t hsmStatus = HSM_REGS->HSM_STATUS;
    
    while (((hsmStatus & HSM_STATUS_BUSY_Msk) != 0) && 
           (((mbTxStatus & HSM_MBTXSTATUS_TXINT_Msk) >> HSM_MBTXSTATUS_TXINT_Pos)  != 1))
    {
        mbTxStatus = HSM_REGS->HSM_MBTXSTATUS;
        hsmStatus = HSM_REGS->HSM_STATUS;        
    }
    
    CmdReq * mbReq = (CmdReq *)(Req);
    uint16_t size = mbReq->mboxHeader.msgSize;
    // Send to the header first.
    HSM_REGS->HSM_MBTXHEAD = mbReq->mboxHeader.v;
    size -= 4;
    uint8_t index = 1;
    while(size != 0)
    {
        HSM_REGS->HSM_MBFIFO[0] = mbReq->v[index];
        index++;
        size-=4;
    }    
    
    return 1;
}

uint32_t RxMbMsg(uint32_t * Rsp)
{
    mboxRxStatus mbRxStatus;
    mbRxStatus.v = HSM_REGS->HSM_MBRXSTATUS;
    
    //SCB_CleanInvalidateDCache_by_Addr(HSM_REGS, sizeof(HSM_REGS));
    volatile uint32_t * mbrxHeaderReg = &HSM_REGS->HSM_MBRXHEAD;
    //volatile uint32_t * fifoRegister = &HSM_REGS->HSM_MBFIFO[0];
    
    uint32_t hsmStatus = HSM_REGS->HSM_STATUS;
    uint8_t ecode = (hsmStatus & HSM_STATUS_ECODE_Msk) >> HSM_STATUS_ECODE_Pos;
    
    while (mbRxStatus.s.rxtInt  != 1)
    {
        //SCB_CleanInvalidateDCache_by_Addr(HSM_REGS, sizeof(HSM_REGS));
        mbRxStatus.v = HSM_REGS->HSM_MBRXSTATUS;
        hsmStatus = HSM_REGS->HSM_STATUS;
        ecode = (hsmStatus & HSM_STATUS_ECODE_Msk) >> HSM_STATUS_ECODE_Pos;
    }
    
    CmdRsp * mbRsp = (CmdRsp *)(Rsp);
    
    //mbRsp->mboxHeader.v = HSM_REGS->HSM_MBRXHEAD;
    MboxRxHeader mbheader;
    mbheader.v = *mbrxHeaderReg;
    mbRsp->mboxHeader.v = mbheader.v;
    
    uint16_t size = mbheader.msgSize;
    size -= 4;
    uint8_t index = 1;
    while(size != 0)
    {
        //SCB_CleanInvalidateDCache_by_Addr(HSM_REGS, sizeof(HSM_REGS));
        uint32_t readValue =  HSM_REGS->HSM_MBFIFO[index];
        mbRsp->v[index] = readValue;
        index++;
        size-=4;        
    }

    return ecode;
}

uint32_t TxRxMbMsg(uint32_t * Req, uint32_t * Rsp)
{
    TxMbMsg(Req);
    RxMbMsg(Rsp);
    return 1;
}

uint32_t RxLoadFirmware()
{
    CmdRsp * cmdRsp = (CmdRsp *)malloc(sizeof(CmdRsp));
    RxMbMsg((uint32_t*)(cmdRsp));
    uint32_t result = cmdRsp->result;
    free((void*)cmdRsp);
    return result;
}

uint32_t TxLoadFirmware(uint32_t loc)
{
    CmdReq * cmdReq = (CmdReq *)malloc(sizeof(CmdReq));
    memset((void*)(cmdReq), 0, sizeof(cmdReq));
    
    cmdReq->mboxHeader.msgSize = 5 * sizeof(uint32_t);
    cmdReq->mboxHeader.unprotected = 1;
    cmdReq->cmdHder.Group = HSM_CG_BOOT;
    cmdReq->cmdHder.CmdId = HSM_BTG_LOADFIRMWARE;
    cmdReq->parameter1 = loc;
    printf("Firmware Metadata: %08lx , %08lx, %08lx, %08lx\r\n",*HFML,*(HFML+1),*(HFML+2),*(HFML+3));
    printf("                   %08lx , %08lx, %08lx\r\n",*(HFML+4),*(HFML+5),*(HFML+6));
    
    TxMbMsg((uint32_t*)(cmdReq));
    
    free((void*)(cmdReq));
    return 1;    
}

uint32_t TxRxLoadFirmware(uint32_t loc)
{
    CmdReq * cmdReq = (CmdReq *)malloc(sizeof(CmdReq));
    memset((void*)(cmdReq), 0, sizeof(cmdReq));
    
    cmdReq->mboxHeader.msgSize = 5 * sizeof(uint32_t);
    cmdReq->mboxHeader.unprotected = 1;
    cmdReq->cmdHder.Group = HSM_CG_BOOT;
    cmdReq->cmdHder.CmdId = HSM_BTG_LOADFIRMWARE;
    cmdReq->parameter1 = loc;
    
    TxMbMsg((uint32_t*)(cmdReq));
    
    free((void*)(cmdReq));
    uint32_t result = RxLoadFirmware();
    return result;    
}

uint32_t TxRxBtFinalizeSb(uint8_t pass)
{
    CmdReq * cmdReq = (CmdReq *)malloc(sizeof(CmdReq));
    memset((void*)(cmdReq), 0, sizeof(cmdReq));
    
    cmdReq->mboxHeader.msgSize = 5 * sizeof(uint32_t);
    cmdReq->cmdHder.Group = HSM_CG_BOOT;
    cmdReq->cmdHder.CmdId = HSM_BTG_FINALIZESB;
    cmdReq->parameter1 = pass;
    
    
    CmdRsp * cmdRsp = (CmdRsp *)malloc(sizeof(CmdRsp));
    TxRxMbMsg((uint32_t*)(cmdReq), (uint32_t*)(cmdRsp));
    uint32_t result = cmdRsp->result;
    free((void*)(cmdReq));
    free((void*)cmdRsp);
    return result;    
}

uint32_t TxRxGetSBC()
{
    CmdReq * cmdReq = (CmdReq *)malloc(sizeof(CmdReq));
    memset((void*)(cmdReq), 0, sizeof(CmdReq));
    
    cmdReq->mboxHeader.msgSize = 4 * sizeof(uint32_t);
    cmdReq->mboxHeader.unprotected = 1;
    cmdReq->cmdHder.Group = HSM_CG_BOOT;
    cmdReq->cmdHder.CmdId = HSM_BTG_GETSBC;
        
    CmdRsp * cmdRsp = (CmdRsp *)malloc(sizeof(CmdRsp));
    TxRxMbMsg((uint32_t*)(cmdReq), (uint32_t*)(cmdRsp));
    uint32_t result = cmdRsp->addInfo;
    printf("GET SBC :");
    switch(result)
    {
        case 0: 
             printf(" DISABLED \r\n");
             break;
        case 1:
             printf(" SIMULTANEOUS \r\n");
             break;
        case 2:
            printf(" SEQUENTIAL \r\n");
            break;
    }
    free((void*)(cmdReq));
    free((void*)cmdRsp);
    return result;   
}


