#ifndef _HSM_H_
#define _HSM_H_

#include <stdint.h>

void hsmTests();
uint32_t TxRxGetSBC();
uint32_t TxLoadFirmware(uint32_t fwmdLoc);
uint32_t TxRxLoadFirmware(uint32_t fwmdLoc);
uint32_t TxRxMbMsg(uint32_t * Req, uint32_t * Rsp);
uint32_t TxRxBtFinalizeSb(uint8_t pass);
uint32_t RxLoadFirmware();
uint32_t TxMbMsg(uint32_t * Req);
uint32_t RxMbMsg(uint32_t * Rsp);

extern uint32_t secureBootPassed;

enum {
    HSM_PS_RESET = 0,
    HSM_PS_BOOT,
    HSM_PS_OPERATION,
    HSM_PS_SAFEMODE
};

enum {
    HSM_LCS_RESET = 0,
    HSM_LCS_ICMANU,
    HSM_LCS_ERASED,
    HSM_LCS_OPEN,
    HSM_LCS_SECURE           
};

enum {
    HSM_SBS_RESET = 0,
    HSM_SBS_DISABLED,
    HSM_SBS_BOOTFLSAUTH,
    HSM_SBS_ADDAUTH,
    HSM_SBS_FAILED,
    HSM_SBS_PASSED,
    HSM_SBS_FWAUTH
};

enum {
    HSM_ECODE_NO_ERROR = 0,
    HSM_ECODE_SELF_TEST_FAIL,
    HSM_ECODE_SEC_FLSH_ERROR,
    HSM_ECODE_LOC_MEM_ERROR,
    HSM_ECODE_FAULT,
    HSM_ECODE_SAFE_MODE_TAMPER,
    HSM_ECODE_SAFE_MODE_HOST,
    HSM_ECODE_HSM_FW_FAIL,
    HSM_ECODE_WDT
};


typedef union
{
    struct {
#pragma pack(push, 1)
        uint16_t msgSize;
        uint8_t msgInfo : 4;
        uint8_t reserved : 1;
        uint8_t unprotected : 1;
        uint8_t privileged : 1;
        uint8_t nonSecure : 1;
        uint8_t userBits;
#pragma pack(pop)
    };
    uint32_t v;
}MboxTxHeader;


typedef union
{
    struct 
    {
    #pragma pack(push, 1)
        uint8_t Group : 8;
        uint8_t CmdId;
        uint8_t : 8;
        uint8_t AuthInc : 1;
        uint8_t HonorSec : 1;
        uint8_t SlotParamInc : 1;
        uint8_t : 5;
    #pragma pack(pop)
    };
    uint32_t v;
}CmdHeader;

typedef union
{
    struct {
#pragma pack(push, 1)
        uint16_t msgSize;
        uint8_t msgInfo : 4;
        uint8_t reserved : 1;
        uint8_t unprotected : 1;
        uint8_t privAccess : 1;
        uint8_t nonSecAccess : 1;
        uint8_t userBits;
#pragma pack(pop)
    };
    uint32_t v;
}MboxRxHeader;

typedef union CmdReqU
{
    struct 
    {
        MboxTxHeader mboxHeader;
        CmdHeader cmdHder;
        uint32_t input;
        uint32_t output;
        uint32_t parameter1;
        uint32_t parameter2;
        uint32_t parameter3;
        uint32_t parameter4;
    };
    uint32_t v[8];
}CmdReq;

typedef union CmdRspU
{
    struct
    {
        MboxRxHeader mboxHeader;
        CmdHeader cmdHdr;
        uint32_t result;
        uint32_t addInfo;
    };
    uint32_t v[4];
}CmdRsp;


typedef union
{
    struct {
#pragma pack(push, 1)
        uint16_t bytesRemaining;
        uint8_t msgInfo : 4;
        uint8_t rxtInt : 1;
        uint8_t rxEmpty : 1;
        uint8_t rxHeader : 1;
        uint8_t  rxError : 1;
#pragma pack(pop)
    } s;
    uint32_t v;
}mboxRxStatus;

enum 
{
    HSM_RC_E_UNKNOWN = 0x00000000U,
    HSM_RC_S_OK = 0x00000001U,
    HSM_RC_E_GENERAL = 0x80000000U,
    HSM_RC_E_CMDCANCEL = 0x80000001U,
    HSM_RC_E_NOTSUPPORTED = 0x80000002U,
    HSM_RC_E_INVPARAM = 0x80000003U,
    HSM_RC_E_INVINPUT = 0x80000004U,
    HSM_RC_E_INPUTDMA = 0x80000005U,
    HSM_RC_E_OUTPUTDMA = 0x80000006U,
    HSM_RC_E_SYSTEMMEM = 0x80000007U,
    HSM_RC_E_INPUTAUTH = 0x80000008U,
    HSM_RC_E_HSMFWAUTH = 0x80000009U,
    HSM_RC_E_HOSTFWAUTH = 0x8000000AU,
    HSM_RC_E_SAFEMODE = 0x8000000BU,
    HSM_RC_E_SELFTEST = 0x8000000CU,
    HSM_RC_E_TIMELOCKED = 0x8000000DU,
    HSM_RC_E_TIMEUNLOCKED = 0x8000000EU,
    HSM_RC_E_TMPRLOCKED = 0x8000000FU,
    HSM_RC_E_TMPRUNLOCKED = 0x80000010U,
    HSM_RC_E_VSINUSE = 0x80000011U,
    HSM_RC_E_VSEMPTY = 0x80000012U,
    HSM_RC_E_NOHSMFW = 0x80000013U,
    HSM_RC_E_INVVS = 0x80000014U,
    HSM_RC_E_HASHFAILED = 0x80000015U,
    HSM_RC_E_FWMDAUTH = 0x80000016U,
    HSM_RC_E_UNKNOWNSBC = 0x80000017U,
    HSM_RC_E_CRYPTOHW = 0x80000018U,
    HSM_RC_E_OUTPUTNOTSET = 0x80000019U,
    HSM_RC_E_INPUTNOTSET = 0x8000001AU,
    HSM_RC_E_OUTPUTSET = 0x8000001BU,
    HSM_RC_E_INPUTSET = 0x8000001CU,
    HSM_RC_E_AUTHBITSET = 0x8000001DU,
    HSM_RC_E_AUTHBITNOTSET = 0x8000001EU,
    HSM_RC_E_SLOTPARASET = 0x8000001FU,
    HSM_RC_E_SLOTPARANOTSET = 0x80000020U,
    HSM_RC_E_INVFORMAT = 0x80000021U,
    HSM_RC_E_OUTPUTTOOSMALL = 0x80000022U,
    HSM_RC_E_OUTOFMEMORY = 0x80000023U,
    HSM_RC_E_INVHASHTYPE = 0x80000024U,
    HSM_RC_E_HOSTFLASHLCK = 0x80000025U,
    HSM_RC_E_HOSTFLASHERASE = 0x80000026U,
    HSM_RC_E_HOSTFLASHREAD = 0x80000027U,
    HSM_RC_E_HOSTFLASHWRITE = 0x80000028U,
    HSM_RC_E_HSMFLASHLCK = 0x80000029U,
    HSM_RC_E_HSMFLASHERASE = 0x8000002AU,
    HSM_RC_E_HSMFLASHREAD = 0x8000002BU,
    HSM_RC_E_HSMFLASHWRITE = 0x8000002CU,
    HSM_RC_E_AESINVALIDMODE = 0x8000002DU,
    HSM_RC_E_AESGCMTAGFAIL = 0x8000002EU,
    HSM_RC_E_INVSIGN = 0x8000002FU,
    HSM_RC_E_INVINPUT2 = 0x80000030U,
    HSM_RC_E_INVOUTPUT = 0x80000031U,
};

enum {
    HSM_SBC_DISABLED = 0,
    HSM_SBC_SIMULTANEOUS,
    HSM_SBC_SEQUENTIAL,
};


enum {
    HSM_CG_BOOT = 0,
};

enum {
    HSM_BTG_GETSBC = 0,
    HSM_BTG_LOADFIRMWARE,
    HSM_BTG_PROCESSFIRMWARE,
    HSM_BTG_FINALIZESB,            
};



#endif